# thedns-sdk-python


### Proposal

The most lightweight module ever to register your devices in seconds.

### Example Code

```ipython
>>>
>>> from thedns import update
>>> update()
{
  'e64ab96324ef1899498889a0e3eabcb4.public.thedns.cn': '106.38.171.243',
  'e64ab96324ef1899498889a0e3eabcb4.private.thedns.cn': '192.168.1.3',
  'fqdn': '/_your_home_/.devnull/fqdn',
  'owner': '_your_email_address_'
 }
>>>

```